from OCC.StlAPI import *
from OCC.TopoDS import TopoDS_Shape
from OCC.Display.SimpleGui import *
from OCC.BRepPrimAPI import *
from OCC.BRepAlgoAPI import *
from OCC.gp import *

import os

display, start_display, add_menu, add_function_to_menu = init_display()

class STLImporter(object):
    def __init__(self,filename):        
        self.SetFilename(filename)
        self._shape = None

    def SetFilename(self, filename):
        if not os.path.isfile(filename):
            print "STEPImporter initialization Error: file %s not found."%filename
            self._filename = None
        else:
            self._filename = filename
       
    def ReadFile(self):
        """
        Read the STEP file and stores the result in a TopoDS_Shape
        """
        stl_reader = StlAPI()
        shp = TopoDS_Shape()
        stl_reader.Read(shp,self._filename)
        self._shape = shp

    def GetShape(self):
        if self._shape.IsNull():
            raise Assertion("Error: the shape is NULL")
        else:
            return self._shape

class STLExporter(object):
    """ A TopoDS_Shape to STL exporter. Default mode is ASCII
    """
    def __init__(self, filename=None,ASCIIMode=True):
        self._shape = None #only one shape can be exported
        self._ASCIIMode = ASCIIMode
        self.SetFilename(filename)
   
    def SetShape(self, aShape):
        # First check the shape
        if aShape.IsNull():
            raise AssertionError("STLExporter Error: the shape is NULL")
        else:
            self._shape = aShape

    def SetFilename(self, filename):
        if not os.path.isfile(filename):
            print "STLImporter initialization Error: file %s not found."%filename
            self._filename = None
        else:
            self._filename = filename
           
    def WriteFile(self):
        stl_writer = StlAPI()
        stl_writer.Write(self._shape,self._filename,self._ASCIIMode)


if __name__ == '__main__':
    
    sh = STLImporter("cylinder.stl")
    sh.SetFilename("cylinder.stl")
    sh.ReadFile()
    
    sh2 = STLImporter("cuboid1.stl")
    sh2.SetFilename("cuboid1.stl")
    sh2.ReadFile()
    
    Box = BRepPrimAPI_MakeBox(200,60,60).Shape()
    
    Sphere = BRepPrimAPI_MakeSphere(gp_Pnt(100,20,20),80).Shape()
    
    ''' Does not work '''
    Cut1 = BRepAlgoAPI_Cut(sh2.GetShape(), sh.GetShape()).Shape() 
    
    """ Does work """
    Cut2 = BRepAlgoAPI_Cut(Sphere, Box).Shape() 
    
    Fuse = BRepAlgoAPI_Fuse(sh2.GetShape(), sh.GetShape()).Shape()
    
    display.EraseAll()
    
    display.DisplayShape(Cut1) #does not work
    display.DisplayShape(Cut2) 
    
    
    start_display()

